@@ -14,6 +14,7 @@
 #include <QObject>
 #include <QPointer>
 #include <QStringList>
+#include <functional>
 #include <memory>
 
 class KCompTreeNode;
@@ -160,12 +161,20 @@ public:
      * completion lookups.
      */
     enum CompOrder {
-        Sorted, ///< Use alphabetically sorted order
+        Sorted, ///< Use alphabetically sorted order or custom sorter logic
         Insertion, ///< Use order of insertion
         Weighted, ///< Use weighted order
     };
     Q_ENUM(CompOrder)
 
+    /**
+     * The sorter function signature. Deriving classes may provide
+     * custom sorting logic via the setSorterFunction method.
+     *
+     * @since 5.88
+     */
+    using SorterFunction = std::function<void(QStringList &)>;
+
     /**
      * Constructor, nothing special here :)
      */
@@ -174,7 +183,7 @@ public:
     /**
      * Destructor, nothing special here, either.
      */
-    virtual ~KCompletion();
+    ~KCompletion() override;
 
     /**
      * Returns a list of all completion items that contain the given @p string.
@@ -398,49 +407,6 @@ public Q_SLOTS:
      */
     QString nextMatch();
 
-#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * Attempts to complete "string" and emits the completion via match().
-     * Same as makeCompletion(), but in this case as a slot.
-     * @param string the string to complete
-     * @see makeCompletion
-     * @deprecated since 5.0, use makeCompletion() instead
-     */
-    KCOMPLETION_DEPRECATED_VERSION(5, 0, "Use KCompletion::makeCompletion(const QString &)")
-    void slotMakeCompletion(const QString &string) // inline (redirect)
-    {
-        (void)makeCompletion(string);
-    }
-#endif
-
-#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * Searches the previous matching item and emits it via match().
-     * Same as previousMatch(), but in this case as a slot.
-     * @see previousMatch
-     * @deprecated since 5.0, use previousMatch() instead
-     */
-    KCOMPLETION_DEPRECATED_VERSION(5, 0, "Use KCompletion::previousMatch()")
-    void slotPreviousMatch() // inline (redirect)
-    {
-        (void)previousMatch();
-    }
-#endif
-
-#if KCOMPLETION_ENABLE_DEPRECATED_SINCE(5, 0)
-    /**
-     * Searches the next matching item and emits it via match().
-     * Same as nextMatch(), but in this case as a slot.
-     * @see nextMatch
-     * @deprecated since 5.0, use nextMatch() instead
-     */
-    KCOMPLETION_DEPRECATED_VERSION(5, 0, "Use KCompletion::nextMatch()")
-    void slotNextMatch() // inline (redirect)
-    {
-        (void)nextMatch();
-    }
-#endif
-
     /**
      * Inserts @p items into the list of possible completions.
      * It does the same as setItems(), but without calling clear() before.
@@ -576,6 +542,15 @@ protected:
      */
     void setShouldAutoSuggest(bool shouldAutosuggest);
 
+    /**
+     * Sets a custom function to be used to sort the matches.
+     * Can be set to nullptr to use the default sorting logic.
+     *
+     * Applies for CompOrder::Sorted mode.
+     * @since 5.88
+     */
+    void setSorterFunction(SorterFunction sortFunc);
+
 private:
     Q_DISABLE_COPY(KCompletion)
     std::unique_ptr<KCompletionPrivate> const d_ptr;
